==> haskell-http-media-0.7.1.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-media.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-media
version: 0.7.1.1
id: http-media-0.7.1.1-7GtPrLmWejF6Fjt4ApRnO
key: http-media-0.7.1.1-7GtPrLmWejF6Fjt4ApRnO
license: MIT
copyright: (c) 2012-2017 Timothy Jones
maintainer: Timothy Jones <tim@zmthy.net>
homepage: https://github.com/zmthy/http-media
synopsis: Processing HTTP Content-Type and Accept headers
description:
    This library is intended to be a comprehensive solution to parsing and
    selecting quality-indexed values in HTTP headers.  It is capable of
    parsing both media types and language parameters from the Accept and
    Content header families, and can be extended to match against other
    accept headers as well.  Selecting the appropriate header value is
    achieved by comparing a list of server options against the
    quality-indexed values supplied by the client.
    .
    In the following example, the Accept header is parsed and then matched
    against a list of server options to serve the appropriate media using
    '\''mapAcceptMedia'\'':
    .
    > getHeader >>= maybe send406Error sendResourceWith . mapAcceptMedia
    >     [ ("text/html",        asHtml)
    >     , ("application/json", asJson)
    >     ]
    .
    Similarly, the Content-Type header can be used to produce a parser for
    request bodies based on the given content type with '\''mapContentMedia'\'':
    .
    > getContentType >>= maybe send415Error readRequestBodyWith . mapContentMedia
    >     [ ("application/json", parseJson)
    >     , ("text/plain",       parseText)
    >     ]
    .
    The API is agnostic to your choice of server.
category: Web
author: Timothy Jones
exposed: True
indefinite: False
exposed-modules:
    Network.HTTP.Media Network.HTTP.Media.Accept
    Network.HTTP.Media.Language Network.HTTP.Media.MediaType
    Network.HTTP.Media.RenderHeader
hidden-modules: Network.HTTP.Media.Language.Internal
                Network.HTTP.Media.MediaType.Internal Network.HTTP.Media.Quality
                Network.HTTP.Media.Utils
abi: ef101fb5035866b66a8d0a5d7fc6ba68
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/http-media-0.7.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/http-media-0.7.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/http-media-0.7.1.1
hs-libraries: HShttp-media-0.7.1.1-7GtPrLmWejF6Fjt4ApRnO
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.10-BoRVwnTiXXU9RJ6NEnu1BA
    containers-0.5.10.2 utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.10-BoRVwnTiXXU9RJ6NEnu1BA=4295449faa2e312746ed6e93c93f9c1e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
haddock-interfaces: /usr/share/doc/haskell-http-media/html/http-media.haddock
haddock-html: /usr/share/doc/haskell-http-media/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-media-0.7.1.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-media.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-media
version: 0.7.1.1
id: http-media-0.7.1.1-IuuqCawlwSgJwW3EeX8Hq7
key: http-media-0.7.1.1-IuuqCawlwSgJwW3EeX8Hq7
license: MIT
copyright: (c) 2012-2017 Timothy Jones
maintainer: Timothy Jones <tim@zmthy.net>
homepage: https://github.com/zmthy/http-media
synopsis: Processing HTTP Content-Type and Accept headers
description:
    This library is intended to be a comprehensive solution to parsing and
    selecting quality-indexed values in HTTP headers.  It is capable of
    parsing both media types and language parameters from the Accept and
    Content header families, and can be extended to match against other
    accept headers as well.  Selecting the appropriate header value is
    achieved by comparing a list of server options against the
    quality-indexed values supplied by the client.
    .
    In the following example, the Accept header is parsed and then matched
    against a list of server options to serve the appropriate media using
    '\''mapAcceptMedia'\'':
    .
    > getHeader >>= maybe send406Error sendResourceWith . mapAcceptMedia
    >     [ ("text/html",        asHtml)
    >     , ("application/json", asJson)
    >     ]
    .
    Similarly, the Content-Type header can be used to produce a parser for
    request bodies based on the given content type with '\''mapContentMedia'\'':
    .
    > getContentType >>= maybe send415Error readRequestBodyWith . mapContentMedia
    >     [ ("application/json", parseJson)
    >     , ("text/plain",       parseText)
    >     ]
    .
    The API is agnostic to your choice of server.
category: Web
author: Timothy Jones
exposed: True
indefinite: False
exposed-modules:
    Network.HTTP.Media Network.HTTP.Media.Accept
    Network.HTTP.Media.Language Network.HTTP.Media.MediaType
    Network.HTTP.Media.RenderHeader
hidden-modules: Network.HTTP.Media.Language.Internal
                Network.HTTP.Media.MediaType.Internal Network.HTTP.Media.Quality
                Network.HTTP.Media.Utils
abi: dadd894b3e1429bdb0ef12015524a7a1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/http-media-0.7.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/http-media-0.7.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/http-media-0.7.1.1
hs-libraries: HShttp-media-0.7.1.1-IuuqCawlwSgJwW3EeX8Hq7
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd
    containers-0.5.10.2 utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd=d2a631059bf8ed4631eaacfed742cab7
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
haddock-interfaces: /usr/share/doc/haskell-http-media/html/http-media.haddock
haddock-html: /usr/share/doc/haskell-http-media/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
